# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ErrorMessages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ErrorMessages.proto',
  package='xgt',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x13\x45rrorMessages.proto\x12\x03xgt\"J\n\x05\x45rror\x12 \n\x04\x63ode\x18\x01 \x01(\x0e\x32\x12.xgt.ErrorCodeEnum\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0e\n\x06\x64\x65tail\x18\x03 \x01(\t*\xa2\x02\n\rErrorCodeEnum\x12\x0c\n\x08NO_ERROR\x10\x00\x12\x11\n\rGENERIC_ERROR\x10\x01\x12\x13\n\x0fNOT_IMPLEMENTED\x10\x02\x12\x12\n\x0eINTERNAL_ERROR\x10\x03\x12\x0c\n\x08IO_ERROR\x10\x04\x12\x17\n\x13SERVER_MEMORY_ERROR\x10\x05\x12\x14\n\x10\x43ONNECTION_ERROR\x10\x06\x12\x10\n\x0cSYNTAX_ERROR\x10\x07\x12\x0e\n\nTYPE_ERROR\x10\x08\x12\x0f\n\x0bVALUE_ERROR\x10\t\x12\x0e\n\nNAME_ERROR\x10\n\x12\x14\n\x10\x41RITHMETIC_ERROR\x10\x0b\x12\x1a\n\x16\x46RAME_DEPENDENCY_ERROR\x10\x0c\x12\x15\n\x11TRANSACTION_ERROR\x10\rb\x06proto3')
)

_ERRORCODEENUM = _descriptor.EnumDescriptor(
  name='ErrorCodeEnum',
  full_name='xgt.ErrorCodeEnum',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_ERROR', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GENERIC_ERROR', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_IMPLEMENTED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IO_ERROR', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVER_MEMORY_ERROR', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONNECTION_ERROR', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SYNTAX_ERROR', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TYPE_ERROR', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VALUE_ERROR', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NAME_ERROR', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ARITHMETIC_ERROR', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FRAME_DEPENDENCY_ERROR', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRANSACTION_ERROR', index=13, number=13,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=105,
  serialized_end=395,
)
_sym_db.RegisterEnumDescriptor(_ERRORCODEENUM)

ErrorCodeEnum = enum_type_wrapper.EnumTypeWrapper(_ERRORCODEENUM)
NO_ERROR = 0
GENERIC_ERROR = 1
NOT_IMPLEMENTED = 2
INTERNAL_ERROR = 3
IO_ERROR = 4
SERVER_MEMORY_ERROR = 5
CONNECTION_ERROR = 6
SYNTAX_ERROR = 7
TYPE_ERROR = 8
VALUE_ERROR = 9
NAME_ERROR = 10
ARITHMETIC_ERROR = 11
FRAME_DEPENDENCY_ERROR = 12
TRANSACTION_ERROR = 13



_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='xgt.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='xgt.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='xgt.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='detail', full_name='xgt.Error.detail', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28,
  serialized_end=102,
)

_ERROR.fields_by_name['code'].enum_type = _ERRORCODEENUM
DESCRIPTOR.message_types_by_name['Error'] = _ERROR
DESCRIPTOR.enum_types_by_name['ErrorCodeEnum'] = _ERRORCODEENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), dict(
  DESCRIPTOR = _ERROR,
  __module__ = 'ErrorMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.Error)
  ))
_sym_db.RegisterMessage(Error)


# @@protoc_insertion_point(module_scope)
