# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GraphTypesService.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ErrorMessages_pb2 as ErrorMessages__pb2
from . import SchemaMessages_pb2 as SchemaMessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='GraphTypesService.proto',
  package='xgt',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x17GraphTypesService.proto\x12\x03xgt\x1a\x13\x45rrorMessages.proto\x1a\x14SchemaMessages.proto\"]\n\x18\x43reateVertexFrameRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12%\n\x0bvertex_type\x18\x02 \x01(\x0b\x32\x10.xgt.VertexFrame\"B\n\x16GetVertexFramesRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x03(\t\"[\n\x17GetVertexFramesResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12%\n\x0bvertex_type\x18\x02 \x03(\x0b\x32\x10.xgt.VertexFrame\"W\n\x16\x43reateEdgeFrameRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12!\n\tedge_type\x18\x02 \x01(\x0b\x32\x0e.xgt.EdgeFrame\"@\n\x14GetEdgeFramesRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x03(\t\"U\n\x15GetEdgeFramesResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12!\n\tedge_type\x18\x02 \x03(\x0b\x32\x0e.xgt.EdgeFrame\"Z\n\x17\x43reateTableFrameRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12#\n\ntable_type\x18\x02 \x01(\x0b\x32\x0f.xgt.TableFrame\"A\n\x15GetTableFramesRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x03(\t\"X\n\x16GetTableFramesResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12#\n\ntable_type\x18\x02 \x03(\x0b\x32\x0f.xgt.TableFrame\"=\n\x11\x44\x65leteTypeRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\"J\n\x12\x44\x65leteTypeResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x19\n\x11\x66ound_and_deleted\x18\x02 \x01(\x08\x32\xae\x04\n\x11GraphTypesService\x12R\n\x11\x43reateVertexFrame\x12\x1d.xgt.CreateVertexFrameRequest\x1a\x1c.xgt.GetVertexFramesResponse\"\x00\x12N\n\x0fGetVertexFrames\x12\x1b.xgt.GetVertexFramesRequest\x1a\x1c.xgt.GetVertexFramesResponse\"\x00\x12L\n\x0f\x43reateEdgeFrame\x12\x1b.xgt.CreateEdgeFrameRequest\x1a\x1a.xgt.GetEdgeFramesResponse\"\x00\x12H\n\rGetEdgeFrames\x12\x19.xgt.GetEdgeFramesRequest\x1a\x1a.xgt.GetEdgeFramesResponse\"\x00\x12O\n\x10\x43reateTableFrame\x12\x1c.xgt.CreateTableFrameRequest\x1a\x1b.xgt.GetTableFramesResponse\"\x00\x12K\n\x0eGetTableFrames\x12\x1a.xgt.GetTableFramesRequest\x1a\x1b.xgt.GetTableFramesResponse\"\x00\x12?\n\nDeleteType\x12\x16.xgt.DeleteTypeRequest\x1a\x17.xgt.DeleteTypeResponse\"\x00\x62\x06proto3')
  ,
  dependencies=[ErrorMessages__pb2.DESCRIPTOR,SchemaMessages__pb2.DESCRIPTOR,])




_CREATEVERTEXFRAMEREQUEST = _descriptor.Descriptor(
  name='CreateVertexFrameRequest',
  full_name='xgt.CreateVertexFrameRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.CreateVertexFrameRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertex_type', full_name='xgt.CreateVertexFrameRequest.vertex_type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=168,
)


_GETVERTEXFRAMESREQUEST = _descriptor.Descriptor(
  name='GetVertexFramesRequest',
  full_name='xgt.GetVertexFramesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.GetVertexFramesRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='xgt.GetVertexFramesRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=170,
  serialized_end=236,
)


_GETVERTEXFRAMESRESPONSE = _descriptor.Descriptor(
  name='GetVertexFramesResponse',
  full_name='xgt.GetVertexFramesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.GetVertexFramesResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertex_type', full_name='xgt.GetVertexFramesResponse.vertex_type', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=329,
)


_CREATEEDGEFRAMEREQUEST = _descriptor.Descriptor(
  name='CreateEdgeFrameRequest',
  full_name='xgt.CreateEdgeFrameRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.CreateEdgeFrameRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='edge_type', full_name='xgt.CreateEdgeFrameRequest.edge_type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=331,
  serialized_end=418,
)


_GETEDGEFRAMESREQUEST = _descriptor.Descriptor(
  name='GetEdgeFramesRequest',
  full_name='xgt.GetEdgeFramesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.GetEdgeFramesRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='xgt.GetEdgeFramesRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=420,
  serialized_end=484,
)


_GETEDGEFRAMESRESPONSE = _descriptor.Descriptor(
  name='GetEdgeFramesResponse',
  full_name='xgt.GetEdgeFramesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.GetEdgeFramesResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='edge_type', full_name='xgt.GetEdgeFramesResponse.edge_type', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=486,
  serialized_end=571,
)


_CREATETABLEFRAMEREQUEST = _descriptor.Descriptor(
  name='CreateTableFrameRequest',
  full_name='xgt.CreateTableFrameRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.CreateTableFrameRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_type', full_name='xgt.CreateTableFrameRequest.table_type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=573,
  serialized_end=663,
)


_GETTABLEFRAMESREQUEST = _descriptor.Descriptor(
  name='GetTableFramesRequest',
  full_name='xgt.GetTableFramesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.GetTableFramesRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='xgt.GetTableFramesRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=665,
  serialized_end=730,
)


_GETTABLEFRAMESRESPONSE = _descriptor.Descriptor(
  name='GetTableFramesResponse',
  full_name='xgt.GetTableFramesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.GetTableFramesResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_type', full_name='xgt.GetTableFramesResponse.table_type', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=732,
  serialized_end=820,
)


_DELETETYPEREQUEST = _descriptor.Descriptor(
  name='DeleteTypeRequest',
  full_name='xgt.DeleteTypeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.DeleteTypeRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='xgt.DeleteTypeRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=822,
  serialized_end=883,
)


_DELETETYPERESPONSE = _descriptor.Descriptor(
  name='DeleteTypeResponse',
  full_name='xgt.DeleteTypeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.DeleteTypeResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='found_and_deleted', full_name='xgt.DeleteTypeResponse.found_and_deleted', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=885,
  serialized_end=959,
)

_CREATEVERTEXFRAMEREQUEST.fields_by_name['vertex_type'].message_type = SchemaMessages__pb2._VERTEXFRAME
_GETVERTEXFRAMESRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_GETVERTEXFRAMESRESPONSE.fields_by_name['vertex_type'].message_type = SchemaMessages__pb2._VERTEXFRAME
_CREATEEDGEFRAMEREQUEST.fields_by_name['edge_type'].message_type = SchemaMessages__pb2._EDGEFRAME
_GETEDGEFRAMESRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_GETEDGEFRAMESRESPONSE.fields_by_name['edge_type'].message_type = SchemaMessages__pb2._EDGEFRAME
_CREATETABLEFRAMEREQUEST.fields_by_name['table_type'].message_type = SchemaMessages__pb2._TABLEFRAME
_GETTABLEFRAMESRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_GETTABLEFRAMESRESPONSE.fields_by_name['table_type'].message_type = SchemaMessages__pb2._TABLEFRAME
_DELETETYPERESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
DESCRIPTOR.message_types_by_name['CreateVertexFrameRequest'] = _CREATEVERTEXFRAMEREQUEST
DESCRIPTOR.message_types_by_name['GetVertexFramesRequest'] = _GETVERTEXFRAMESREQUEST
DESCRIPTOR.message_types_by_name['GetVertexFramesResponse'] = _GETVERTEXFRAMESRESPONSE
DESCRIPTOR.message_types_by_name['CreateEdgeFrameRequest'] = _CREATEEDGEFRAMEREQUEST
DESCRIPTOR.message_types_by_name['GetEdgeFramesRequest'] = _GETEDGEFRAMESREQUEST
DESCRIPTOR.message_types_by_name['GetEdgeFramesResponse'] = _GETEDGEFRAMESRESPONSE
DESCRIPTOR.message_types_by_name['CreateTableFrameRequest'] = _CREATETABLEFRAMEREQUEST
DESCRIPTOR.message_types_by_name['GetTableFramesRequest'] = _GETTABLEFRAMESREQUEST
DESCRIPTOR.message_types_by_name['GetTableFramesResponse'] = _GETTABLEFRAMESRESPONSE
DESCRIPTOR.message_types_by_name['DeleteTypeRequest'] = _DELETETYPEREQUEST
DESCRIPTOR.message_types_by_name['DeleteTypeResponse'] = _DELETETYPERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateVertexFrameRequest = _reflection.GeneratedProtocolMessageType('CreateVertexFrameRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATEVERTEXFRAMEREQUEST,
  __module__ = 'GraphTypesService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.CreateVertexFrameRequest)
  ))
_sym_db.RegisterMessage(CreateVertexFrameRequest)

GetVertexFramesRequest = _reflection.GeneratedProtocolMessageType('GetVertexFramesRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETVERTEXFRAMESREQUEST,
  __module__ = 'GraphTypesService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetVertexFramesRequest)
  ))
_sym_db.RegisterMessage(GetVertexFramesRequest)

GetVertexFramesResponse = _reflection.GeneratedProtocolMessageType('GetVertexFramesResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETVERTEXFRAMESRESPONSE,
  __module__ = 'GraphTypesService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetVertexFramesResponse)
  ))
_sym_db.RegisterMessage(GetVertexFramesResponse)

CreateEdgeFrameRequest = _reflection.GeneratedProtocolMessageType('CreateEdgeFrameRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATEEDGEFRAMEREQUEST,
  __module__ = 'GraphTypesService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.CreateEdgeFrameRequest)
  ))
_sym_db.RegisterMessage(CreateEdgeFrameRequest)

GetEdgeFramesRequest = _reflection.GeneratedProtocolMessageType('GetEdgeFramesRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETEDGEFRAMESREQUEST,
  __module__ = 'GraphTypesService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetEdgeFramesRequest)
  ))
_sym_db.RegisterMessage(GetEdgeFramesRequest)

GetEdgeFramesResponse = _reflection.GeneratedProtocolMessageType('GetEdgeFramesResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETEDGEFRAMESRESPONSE,
  __module__ = 'GraphTypesService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetEdgeFramesResponse)
  ))
_sym_db.RegisterMessage(GetEdgeFramesResponse)

CreateTableFrameRequest = _reflection.GeneratedProtocolMessageType('CreateTableFrameRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATETABLEFRAMEREQUEST,
  __module__ = 'GraphTypesService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.CreateTableFrameRequest)
  ))
_sym_db.RegisterMessage(CreateTableFrameRequest)

GetTableFramesRequest = _reflection.GeneratedProtocolMessageType('GetTableFramesRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETTABLEFRAMESREQUEST,
  __module__ = 'GraphTypesService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetTableFramesRequest)
  ))
_sym_db.RegisterMessage(GetTableFramesRequest)

GetTableFramesResponse = _reflection.GeneratedProtocolMessageType('GetTableFramesResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETTABLEFRAMESRESPONSE,
  __module__ = 'GraphTypesService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetTableFramesResponse)
  ))
_sym_db.RegisterMessage(GetTableFramesResponse)

DeleteTypeRequest = _reflection.GeneratedProtocolMessageType('DeleteTypeRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETETYPEREQUEST,
  __module__ = 'GraphTypesService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.DeleteTypeRequest)
  ))
_sym_db.RegisterMessage(DeleteTypeRequest)

DeleteTypeResponse = _reflection.GeneratedProtocolMessageType('DeleteTypeResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETETYPERESPONSE,
  __module__ = 'GraphTypesService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.DeleteTypeResponse)
  ))
_sym_db.RegisterMessage(DeleteTypeResponse)



_GRAPHTYPESSERVICE = _descriptor.ServiceDescriptor(
  name='GraphTypesService',
  full_name='xgt.GraphTypesService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=962,
  serialized_end=1520,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateVertexFrame',
    full_name='xgt.GraphTypesService.CreateVertexFrame',
    index=0,
    containing_service=None,
    input_type=_CREATEVERTEXFRAMEREQUEST,
    output_type=_GETVERTEXFRAMESRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetVertexFrames',
    full_name='xgt.GraphTypesService.GetVertexFrames',
    index=1,
    containing_service=None,
    input_type=_GETVERTEXFRAMESREQUEST,
    output_type=_GETVERTEXFRAMESRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreateEdgeFrame',
    full_name='xgt.GraphTypesService.CreateEdgeFrame',
    index=2,
    containing_service=None,
    input_type=_CREATEEDGEFRAMEREQUEST,
    output_type=_GETEDGEFRAMESRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetEdgeFrames',
    full_name='xgt.GraphTypesService.GetEdgeFrames',
    index=3,
    containing_service=None,
    input_type=_GETEDGEFRAMESREQUEST,
    output_type=_GETEDGEFRAMESRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreateTableFrame',
    full_name='xgt.GraphTypesService.CreateTableFrame',
    index=4,
    containing_service=None,
    input_type=_CREATETABLEFRAMEREQUEST,
    output_type=_GETTABLEFRAMESRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetTableFrames',
    full_name='xgt.GraphTypesService.GetTableFrames',
    index=5,
    containing_service=None,
    input_type=_GETTABLEFRAMESREQUEST,
    output_type=_GETTABLEFRAMESRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteType',
    full_name='xgt.GraphTypesService.DeleteType',
    index=6,
    containing_service=None,
    input_type=_DELETETYPEREQUEST,
    output_type=_DELETETYPERESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_GRAPHTYPESSERVICE)

DESCRIPTOR.services_by_name['GraphTypesService'] = _GRAPHTYPESSERVICE

# @@protoc_insertion_point(module_scope)
