# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import GraphTypesService_pb2 as GraphTypesService__pb2


class GraphTypesServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.CreateVertexFrame = channel.unary_unary(
        '/xgt.GraphTypesService/CreateVertexFrame',
        request_serializer=GraphTypesService__pb2.CreateVertexFrameRequest.SerializeToString,
        response_deserializer=GraphTypesService__pb2.GetVertexFramesResponse.FromString,
        )
    self.GetVertexFrames = channel.unary_unary(
        '/xgt.GraphTypesService/GetVertexFrames',
        request_serializer=GraphTypesService__pb2.GetVertexFramesRequest.SerializeToString,
        response_deserializer=GraphTypesService__pb2.GetVertexFramesResponse.FromString,
        )
    self.CreateEdgeFrame = channel.unary_unary(
        '/xgt.GraphTypesService/CreateEdgeFrame',
        request_serializer=GraphTypesService__pb2.CreateEdgeFrameRequest.SerializeToString,
        response_deserializer=GraphTypesService__pb2.GetEdgeFramesResponse.FromString,
        )
    self.GetEdgeFrames = channel.unary_unary(
        '/xgt.GraphTypesService/GetEdgeFrames',
        request_serializer=GraphTypesService__pb2.GetEdgeFramesRequest.SerializeToString,
        response_deserializer=GraphTypesService__pb2.GetEdgeFramesResponse.FromString,
        )
    self.CreateTableFrame = channel.unary_unary(
        '/xgt.GraphTypesService/CreateTableFrame',
        request_serializer=GraphTypesService__pb2.CreateTableFrameRequest.SerializeToString,
        response_deserializer=GraphTypesService__pb2.GetTableFramesResponse.FromString,
        )
    self.GetTableFrames = channel.unary_unary(
        '/xgt.GraphTypesService/GetTableFrames',
        request_serializer=GraphTypesService__pb2.GetTableFramesRequest.SerializeToString,
        response_deserializer=GraphTypesService__pb2.GetTableFramesResponse.FromString,
        )
    self.DeleteType = channel.unary_unary(
        '/xgt.GraphTypesService/DeleteType',
        request_serializer=GraphTypesService__pb2.DeleteTypeRequest.SerializeToString,
        response_deserializer=GraphTypesService__pb2.DeleteTypeResponse.FromString,
        )


class GraphTypesServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def CreateVertexFrame(self, request, context):
    """Vertex frames
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetVertexFrames(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreateEdgeFrame(self, request, context):
    """Edge frames
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetEdgeFrames(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreateTableFrame(self, request, context):
    """Table frames
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetTableFrames(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteType(self, request, context):
    """Multi-type functions
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_GraphTypesServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'CreateVertexFrame': grpc.unary_unary_rpc_method_handler(
          servicer.CreateVertexFrame,
          request_deserializer=GraphTypesService__pb2.CreateVertexFrameRequest.FromString,
          response_serializer=GraphTypesService__pb2.GetVertexFramesResponse.SerializeToString,
      ),
      'GetVertexFrames': grpc.unary_unary_rpc_method_handler(
          servicer.GetVertexFrames,
          request_deserializer=GraphTypesService__pb2.GetVertexFramesRequest.FromString,
          response_serializer=GraphTypesService__pb2.GetVertexFramesResponse.SerializeToString,
      ),
      'CreateEdgeFrame': grpc.unary_unary_rpc_method_handler(
          servicer.CreateEdgeFrame,
          request_deserializer=GraphTypesService__pb2.CreateEdgeFrameRequest.FromString,
          response_serializer=GraphTypesService__pb2.GetEdgeFramesResponse.SerializeToString,
      ),
      'GetEdgeFrames': grpc.unary_unary_rpc_method_handler(
          servicer.GetEdgeFrames,
          request_deserializer=GraphTypesService__pb2.GetEdgeFramesRequest.FromString,
          response_serializer=GraphTypesService__pb2.GetEdgeFramesResponse.SerializeToString,
      ),
      'CreateTableFrame': grpc.unary_unary_rpc_method_handler(
          servicer.CreateTableFrame,
          request_deserializer=GraphTypesService__pb2.CreateTableFrameRequest.FromString,
          response_serializer=GraphTypesService__pb2.GetTableFramesResponse.SerializeToString,
      ),
      'GetTableFrames': grpc.unary_unary_rpc_method_handler(
          servicer.GetTableFrames,
          request_deserializer=GraphTypesService__pb2.GetTableFramesRequest.FromString,
          response_serializer=GraphTypesService__pb2.GetTableFramesResponse.SerializeToString,
      ),
      'DeleteType': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteType,
          request_deserializer=GraphTypesService__pb2.DeleteTypeRequest.FromString,
          response_serializer=GraphTypesService__pb2.DeleteTypeResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'xgt.GraphTypesService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
