# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SchemaMessages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='SchemaMessages.proto',
  package='xgt',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x14SchemaMessages.proto\x12\x03xgt\"[\n\x08Property\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\tdata_type\x18\x02 \x01(\x0e\x32\x11.xgt.UvalTypeEnum\x12\x1b\n\x04role\x18\x03 \x01(\x0e\x32\r.xgt.RoleEnum\")\n\x06Schema\x12\x1f\n\x08property\x18\x01 \x03(\x0b\x32\r.xgt.Property\"Z\n\nTableFrame\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1b\n\x06schema\x18\x02 \x01(\x0b\x32\x0b.xgt.Schema\x12\r\n\x05nrows\x18\x03 \x01(\x04\x12\x12\n\nerror_name\x18\x04 \x01(\t\"_\n\x0bVertexFrame\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnvertices\x18\x02 \x01(\x04\x12\x1b\n\x06schema\x18\x03 \x01(\x0b\x32\x0b.xgt.Schema\x12\x12\n\nerror_name\x18\x04 \x01(\t\"\xb0\x01\n\tEdgeFrame\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06nedges\x18\x02 \x01(\x04\x12\x1b\n\x06schema\x18\x03 \x01(\x0b\x32\x0b.xgt.Schema\x12\x15\n\rsource_vertex\x18\x04 \x01(\t\x12\x15\n\rtarget_vertex\x18\x05 \x01(\t\x12\x12\n\nsource_key\x18\x06 \x01(\t\x12\x12\n\ntarget_key\x18\x07 \x01(\t\x12\x12\n\nerror_name\x18\x08 \x01(\t*\x8e\x01\n\x0cUvalTypeEnum\x12\x15\n\x11UNKNOWN_UVAL_TYPE\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0b\n\x07\x42OOLEAN\x10\x02\x12\x07\n\x03INT\x10\x03\x12\t\n\x05\x46LOAT\x10\x04\x12\x08\n\x04\x44\x41TE\x10\x05\x12\x08\n\x04TIME\x10\x06\x12\x0c\n\x08\x44\x41TETIME\x10\x07\x12\r\n\tIPADDRESS\x10\x08\x12\x08\n\x04TEXT\x10\t*R\n\x08RoleEnum\x12\x0c\n\x08PROPERTY\x10\x00\x12\x0e\n\nVERTEX_KEY\x10\x01\x12\x13\n\x0f\x45\x44GE_SOURCE_KEY\x10\x02\x12\x13\n\x0f\x45\x44GE_TARGET_KEY\x10\x03\x62\x06proto3')
)

_UVALTYPEENUM = _descriptor.EnumDescriptor(
  name='UvalTypeEnum',
  full_name='xgt.UvalTypeEnum',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_UVAL_TYPE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOOLEAN', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INT', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLOAT', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIME', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATETIME', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IPADDRESS', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEXT', index=9, number=9,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=534,
  serialized_end=676,
)
_sym_db.RegisterEnumDescriptor(_UVALTYPEENUM)

UvalTypeEnum = enum_type_wrapper.EnumTypeWrapper(_UVALTYPEENUM)
_ROLEENUM = _descriptor.EnumDescriptor(
  name='RoleEnum',
  full_name='xgt.RoleEnum',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PROPERTY', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERTEX_KEY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EDGE_SOURCE_KEY', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EDGE_TARGET_KEY', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=678,
  serialized_end=760,
)
_sym_db.RegisterEnumDescriptor(_ROLEENUM)

RoleEnum = enum_type_wrapper.EnumTypeWrapper(_ROLEENUM)
UNKNOWN_UVAL_TYPE = 0
UNKNOWN = 1
BOOLEAN = 2
INT = 3
FLOAT = 4
DATE = 5
TIME = 6
DATETIME = 7
IPADDRESS = 8
TEXT = 9
PROPERTY = 0
VERTEX_KEY = 1
EDGE_SOURCE_KEY = 2
EDGE_TARGET_KEY = 3



_PROPERTY = _descriptor.Descriptor(
  name='Property',
  full_name='xgt.Property',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='xgt.Property.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='xgt.Property.data_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='role', full_name='xgt.Property.role', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29,
  serialized_end=120,
)


_SCHEMA = _descriptor.Descriptor(
  name='Schema',
  full_name='xgt.Schema',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='property', full_name='xgt.Schema.property', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=122,
  serialized_end=163,
)


_TABLEFRAME = _descriptor.Descriptor(
  name='TableFrame',
  full_name='xgt.TableFrame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='xgt.TableFrame.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schema', full_name='xgt.TableFrame.schema', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nrows', full_name='xgt.TableFrame.nrows', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_name', full_name='xgt.TableFrame.error_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=165,
  serialized_end=255,
)


_VERTEXFRAME = _descriptor.Descriptor(
  name='VertexFrame',
  full_name='xgt.VertexFrame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='xgt.VertexFrame.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nvertices', full_name='xgt.VertexFrame.nvertices', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schema', full_name='xgt.VertexFrame.schema', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_name', full_name='xgt.VertexFrame.error_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=257,
  serialized_end=352,
)


_EDGEFRAME = _descriptor.Descriptor(
  name='EdgeFrame',
  full_name='xgt.EdgeFrame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='xgt.EdgeFrame.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nedges', full_name='xgt.EdgeFrame.nedges', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schema', full_name='xgt.EdgeFrame.schema', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_vertex', full_name='xgt.EdgeFrame.source_vertex', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_vertex', full_name='xgt.EdgeFrame.target_vertex', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_key', full_name='xgt.EdgeFrame.source_key', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_key', full_name='xgt.EdgeFrame.target_key', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_name', full_name='xgt.EdgeFrame.error_name', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=355,
  serialized_end=531,
)

_PROPERTY.fields_by_name['data_type'].enum_type = _UVALTYPEENUM
_PROPERTY.fields_by_name['role'].enum_type = _ROLEENUM
_SCHEMA.fields_by_name['property'].message_type = _PROPERTY
_TABLEFRAME.fields_by_name['schema'].message_type = _SCHEMA
_VERTEXFRAME.fields_by_name['schema'].message_type = _SCHEMA
_EDGEFRAME.fields_by_name['schema'].message_type = _SCHEMA
DESCRIPTOR.message_types_by_name['Property'] = _PROPERTY
DESCRIPTOR.message_types_by_name['Schema'] = _SCHEMA
DESCRIPTOR.message_types_by_name['TableFrame'] = _TABLEFRAME
DESCRIPTOR.message_types_by_name['VertexFrame'] = _VERTEXFRAME
DESCRIPTOR.message_types_by_name['EdgeFrame'] = _EDGEFRAME
DESCRIPTOR.enum_types_by_name['UvalTypeEnum'] = _UVALTYPEENUM
DESCRIPTOR.enum_types_by_name['RoleEnum'] = _ROLEENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Property = _reflection.GeneratedProtocolMessageType('Property', (_message.Message,), dict(
  DESCRIPTOR = _PROPERTY,
  __module__ = 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.Property)
  ))
_sym_db.RegisterMessage(Property)

Schema = _reflection.GeneratedProtocolMessageType('Schema', (_message.Message,), dict(
  DESCRIPTOR = _SCHEMA,
  __module__ = 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.Schema)
  ))
_sym_db.RegisterMessage(Schema)

TableFrame = _reflection.GeneratedProtocolMessageType('TableFrame', (_message.Message,), dict(
  DESCRIPTOR = _TABLEFRAME,
  __module__ = 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.TableFrame)
  ))
_sym_db.RegisterMessage(TableFrame)

VertexFrame = _reflection.GeneratedProtocolMessageType('VertexFrame', (_message.Message,), dict(
  DESCRIPTOR = _VERTEXFRAME,
  __module__ = 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.VertexFrame)
  ))
_sym_db.RegisterMessage(VertexFrame)

EdgeFrame = _reflection.GeneratedProtocolMessageType('EdgeFrame', (_message.Message,), dict(
  DESCRIPTOR = _EDGEFRAME,
  __module__ = 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.EdgeFrame)
  ))
_sym_db.RegisterMessage(EdgeFrame)


# @@protoc_insertion_point(module_scope)
