# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import AdminService_pb2 as AdminService__pb2


class AdminServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.ChangeErrorCount = channel.unary_unary(
        '/xgt.AdminService/ChangeErrorCount',
        request_serializer=AdminService__pb2.ChangeErrorCountRequest.SerializeToString,
        response_deserializer=AdminService__pb2.ChangeErrorCountResponse.FromString,
        )
    self.Identifier = channel.unary_unary(
        '/xgt.AdminService/Identifier',
        request_serializer=AdminService__pb2.IdentifierRequest.SerializeToString,
        response_deserializer=AdminService__pb2.IdentifierResponse.FromString,
        )
    self.FreeUserMemorySize = channel.unary_unary(
        '/xgt.AdminService/FreeUserMemorySize',
        request_serializer=AdminService__pb2.FreeUserMemorySizeRequest.SerializeToString,
        response_deserializer=AdminService__pb2.FreeUserMemorySizeResponse.FromString,
        )
    self.MaxUserMemorySize = channel.unary_unary(
        '/xgt.AdminService/MaxUserMemorySize',
        request_serializer=AdminService__pb2.MaxUserMemorySizeRequest.SerializeToString,
        response_deserializer=AdminService__pb2.MaxUserMemorySizeResponse.FromString,
        )
    self.Shutdown = channel.unary_unary(
        '/xgt.AdminService/Shutdown',
        request_serializer=AdminService__pb2.ShutdownRequest.SerializeToString,
        response_deserializer=AdminService__pb2.ShutdownResponse.FromString,
        )
    self.StatReport = channel.unary_unary(
        '/xgt.AdminService/StatReport',
        request_serializer=AdminService__pb2.StatReportRequest.SerializeToString,
        response_deserializer=AdminService__pb2.StatReportResponse.FromString,
        )
    self.StatReset = channel.unary_unary(
        '/xgt.AdminService/StatReset',
        request_serializer=AdminService__pb2.StatResetRequest.SerializeToString,
        response_deserializer=AdminService__pb2.StatResetResponse.FromString,
        )
    self.Version = channel.unary_unary(
        '/xgt.AdminService/Version',
        request_serializer=AdminService__pb2.VersionRequest.SerializeToString,
        response_deserializer=AdminService__pb2.VersionResponse.FromString,
        )


class AdminServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def ChangeErrorCount(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Identifier(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def FreeUserMemorySize(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MaxUserMemorySize(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Shutdown(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def StatReport(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def StatReset(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Version(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AdminServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'ChangeErrorCount': grpc.unary_unary_rpc_method_handler(
          servicer.ChangeErrorCount,
          request_deserializer=AdminService__pb2.ChangeErrorCountRequest.FromString,
          response_serializer=AdminService__pb2.ChangeErrorCountResponse.SerializeToString,
      ),
      'Identifier': grpc.unary_unary_rpc_method_handler(
          servicer.Identifier,
          request_deserializer=AdminService__pb2.IdentifierRequest.FromString,
          response_serializer=AdminService__pb2.IdentifierResponse.SerializeToString,
      ),
      'FreeUserMemorySize': grpc.unary_unary_rpc_method_handler(
          servicer.FreeUserMemorySize,
          request_deserializer=AdminService__pb2.FreeUserMemorySizeRequest.FromString,
          response_serializer=AdminService__pb2.FreeUserMemorySizeResponse.SerializeToString,
      ),
      'MaxUserMemorySize': grpc.unary_unary_rpc_method_handler(
          servicer.MaxUserMemorySize,
          request_deserializer=AdminService__pb2.MaxUserMemorySizeRequest.FromString,
          response_serializer=AdminService__pb2.MaxUserMemorySizeResponse.SerializeToString,
      ),
      'Shutdown': grpc.unary_unary_rpc_method_handler(
          servicer.Shutdown,
          request_deserializer=AdminService__pb2.ShutdownRequest.FromString,
          response_serializer=AdminService__pb2.ShutdownResponse.SerializeToString,
      ),
      'StatReport': grpc.unary_unary_rpc_method_handler(
          servicer.StatReport,
          request_deserializer=AdminService__pb2.StatReportRequest.FromString,
          response_serializer=AdminService__pb2.StatReportResponse.SerializeToString,
      ),
      'StatReset': grpc.unary_unary_rpc_method_handler(
          servicer.StatReset,
          request_deserializer=AdminService__pb2.StatResetRequest.FromString,
          response_serializer=AdminService__pb2.StatResetResponse.SerializeToString,
      ),
      'Version': grpc.unary_unary_rpc_method_handler(
          servicer.Version,
          request_deserializer=AdminService__pb2.VersionRequest.FromString,
          response_serializer=AdminService__pb2.VersionResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'xgt.AdminService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
