# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import DataService_pb2 as DataService__pb2


class DataServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.UploadData = channel.stream_unary(
        '/xgt.DataService/UploadData',
        request_serializer=DataService__pb2.UploadDataRequest.SerializeToString,
        response_deserializer=DataService__pb2.UploadDataResponse.FromString,
        )
    self.DownloadData = channel.unary_stream(
        '/xgt.DataService/DownloadData',
        request_serializer=DataService__pb2.DownloadDataRequest.SerializeToString,
        response_deserializer=DataService__pb2.DownloadDataResponse.FromString,
        )
    self.IngestUri = channel.unary_unary(
        '/xgt.DataService/IngestUri',
        request_serializer=DataService__pb2.IngestUriRequest.SerializeToString,
        response_deserializer=DataService__pb2.IngestUriResponse.FromString,
        )
    self.EgestUri = channel.unary_unary(
        '/xgt.DataService/EgestUri',
        request_serializer=DataService__pb2.EgestUriRequest.SerializeToString,
        response_deserializer=DataService__pb2.EgestUriResponse.FromString,
        )


class DataServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def UploadData(self, request_iterator, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DownloadData(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def IngestUri(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EgestUri(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DataServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'UploadData': grpc.stream_unary_rpc_method_handler(
          servicer.UploadData,
          request_deserializer=DataService__pb2.UploadDataRequest.FromString,
          response_serializer=DataService__pb2.UploadDataResponse.SerializeToString,
      ),
      'DownloadData': grpc.unary_stream_rpc_method_handler(
          servicer.DownloadData,
          request_deserializer=DataService__pb2.DownloadDataRequest.FromString,
          response_serializer=DataService__pb2.DownloadDataResponse.SerializeToString,
      ),
      'IngestUri': grpc.unary_unary_rpc_method_handler(
          servicer.IngestUri,
          request_deserializer=DataService__pb2.IngestUriRequest.FromString,
          response_serializer=DataService__pb2.IngestUriResponse.SerializeToString,
      ),
      'EgestUri': grpc.unary_unary_rpc_method_handler(
          servicer.EgestUri,
          request_deserializer=DataService__pb2.EgestUriRequest.FromString,
          response_serializer=DataService__pb2.EgestUriResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'xgt.DataService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
