# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: JobService.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ErrorMessages_pb2 as ErrorMessages__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='JobService.proto',
  package='xgt',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x10JobService.proto\x12\x03xgt\x1a\x13\x45rrorMessages.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb8\x01\n\tJobStatus\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x0e\n\x06job_id\x18\x02 \x01(\x04\x12\"\n\x06status\x18\x03 \x01(\x0e\x32\x12.xgt.JobStatusEnum\x12.\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"i\n\x19ScheduleJobsCypherRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12\x14\n\x0c\x63ypher_query\x18\x02 \x03(\t\x12\x1a\n\x12optimization_level\x18\x03 \x01(\x05\"[\n\x1aScheduleJobsCypherResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\"\n\njob_status\x18\x02 \x03(\x0b\x32\x0e.xgt.JobStatus\"?\n\x11\x43\x61ncelJobsRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12\x0e\n\x06job_id\x18\x02 \x03(\x04\"S\n\x12\x43\x61ncelJobsResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\"\n\njob_status\x18\x02 \x03(\x0b\x32\x0e.xgt.JobStatus\"<\n\x0eGetJobsRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12\x0e\n\x06job_id\x18\x02 \x03(\x04\"P\n\x0fGetJobsResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\"\n\njob_status\x18\x02 \x03(\x0b\x32\x0e.xgt.JobStatus*\xbf\x01\n\rJobStatusEnum\x12\x16\n\x12UNKNOWN_JOB_STATUS\x10\x00\x12\r\n\tSCHEDULED\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\r\n\tCOMPLETED\x10\x03\x12\x0c\n\x08\x43\x41NCELED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x12\x19\n\x15TRANSACTIONNOTSTARTED\x10\x06\x12\x19\n\x15TRANSACTIONCOMMITTING\x10\x07\x12\x1b\n\x17TRANSACTIONNOTCOMMITTED\x10\x08\x32\xde\x01\n\nJobService\x12W\n\x12ScheduleJobsCypher\x12\x1e.xgt.ScheduleJobsCypherRequest\x1a\x1f.xgt.ScheduleJobsCypherResponse\"\x00\x12?\n\nCancelJobs\x12\x16.xgt.CancelJobsRequest\x1a\x17.xgt.CancelJobsResponse\"\x00\x12\x36\n\x07GetJobs\x12\x13.xgt.GetJobsRequest\x1a\x14.xgt.GetJobsResponse\"\x00\x62\x06proto3')
  ,
  dependencies=[ErrorMessages__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_JOBSTATUSENUM = _descriptor.EnumDescriptor(
  name='JobStatusEnum',
  full_name='xgt.JobStatusEnum',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_JOB_STATUS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCHEDULED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPLETED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRANSACTIONNOTSTARTED', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRANSACTIONCOMMITTING', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRANSACTIONNOTCOMMITTED', index=8, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=761,
  serialized_end=952,
)
_sym_db.RegisterEnumDescriptor(_JOBSTATUSENUM)

JobStatusEnum = enum_type_wrapper.EnumTypeWrapper(_JOBSTATUSENUM)
UNKNOWN_JOB_STATUS = 0
SCHEDULED = 1
RUNNING = 2
COMPLETED = 3
CANCELED = 4
FAILED = 5
TRANSACTIONNOTSTARTED = 6
TRANSACTIONCOMMITTING = 7
TRANSACTIONNOTCOMMITTED = 8



_JOBSTATUS = _descriptor.Descriptor(
  name='JobStatus',
  full_name='xgt.JobStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.JobStatus.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='xgt.JobStatus.job_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='xgt.JobStatus.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='xgt.JobStatus.start_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='xgt.JobStatus.end_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=264,
)


_SCHEDULEJOBSCYPHERREQUEST = _descriptor.Descriptor(
  name='ScheduleJobsCypherRequest',
  full_name='xgt.ScheduleJobsCypherRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.ScheduleJobsCypherRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cypher_query', full_name='xgt.ScheduleJobsCypherRequest.cypher_query', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optimization_level', full_name='xgt.ScheduleJobsCypherRequest.optimization_level', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=266,
  serialized_end=371,
)


_SCHEDULEJOBSCYPHERRESPONSE = _descriptor.Descriptor(
  name='ScheduleJobsCypherResponse',
  full_name='xgt.ScheduleJobsCypherResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.ScheduleJobsCypherResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_status', full_name='xgt.ScheduleJobsCypherResponse.job_status', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=373,
  serialized_end=464,
)


_CANCELJOBSREQUEST = _descriptor.Descriptor(
  name='CancelJobsRequest',
  full_name='xgt.CancelJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.CancelJobsRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='xgt.CancelJobsRequest.job_id', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=466,
  serialized_end=529,
)


_CANCELJOBSRESPONSE = _descriptor.Descriptor(
  name='CancelJobsResponse',
  full_name='xgt.CancelJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.CancelJobsResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_status', full_name='xgt.CancelJobsResponse.job_status', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=531,
  serialized_end=614,
)


_GETJOBSREQUEST = _descriptor.Descriptor(
  name='GetJobsRequest',
  full_name='xgt.GetJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.GetJobsRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='xgt.GetJobsRequest.job_id', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=616,
  serialized_end=676,
)


_GETJOBSRESPONSE = _descriptor.Descriptor(
  name='GetJobsResponse',
  full_name='xgt.GetJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.GetJobsResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_status', full_name='xgt.GetJobsResponse.job_status', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=678,
  serialized_end=758,
)

_JOBSTATUS.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_JOBSTATUS.fields_by_name['status'].enum_type = _JOBSTATUSENUM
_JOBSTATUS.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOBSTATUS.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCHEDULEJOBSCYPHERRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_SCHEDULEJOBSCYPHERRESPONSE.fields_by_name['job_status'].message_type = _JOBSTATUS
_CANCELJOBSRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_CANCELJOBSRESPONSE.fields_by_name['job_status'].message_type = _JOBSTATUS
_GETJOBSRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_GETJOBSRESPONSE.fields_by_name['job_status'].message_type = _JOBSTATUS
DESCRIPTOR.message_types_by_name['JobStatus'] = _JOBSTATUS
DESCRIPTOR.message_types_by_name['ScheduleJobsCypherRequest'] = _SCHEDULEJOBSCYPHERREQUEST
DESCRIPTOR.message_types_by_name['ScheduleJobsCypherResponse'] = _SCHEDULEJOBSCYPHERRESPONSE
DESCRIPTOR.message_types_by_name['CancelJobsRequest'] = _CANCELJOBSREQUEST
DESCRIPTOR.message_types_by_name['CancelJobsResponse'] = _CANCELJOBSRESPONSE
DESCRIPTOR.message_types_by_name['GetJobsRequest'] = _GETJOBSREQUEST
DESCRIPTOR.message_types_by_name['GetJobsResponse'] = _GETJOBSRESPONSE
DESCRIPTOR.enum_types_by_name['JobStatusEnum'] = _JOBSTATUSENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

JobStatus = _reflection.GeneratedProtocolMessageType('JobStatus', (_message.Message,), dict(
  DESCRIPTOR = _JOBSTATUS,
  __module__ = 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.JobStatus)
  ))
_sym_db.RegisterMessage(JobStatus)

ScheduleJobsCypherRequest = _reflection.GeneratedProtocolMessageType('ScheduleJobsCypherRequest', (_message.Message,), dict(
  DESCRIPTOR = _SCHEDULEJOBSCYPHERREQUEST,
  __module__ = 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ScheduleJobsCypherRequest)
  ))
_sym_db.RegisterMessage(ScheduleJobsCypherRequest)

ScheduleJobsCypherResponse = _reflection.GeneratedProtocolMessageType('ScheduleJobsCypherResponse', (_message.Message,), dict(
  DESCRIPTOR = _SCHEDULEJOBSCYPHERRESPONSE,
  __module__ = 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ScheduleJobsCypherResponse)
  ))
_sym_db.RegisterMessage(ScheduleJobsCypherResponse)

CancelJobsRequest = _reflection.GeneratedProtocolMessageType('CancelJobsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CANCELJOBSREQUEST,
  __module__ = 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.CancelJobsRequest)
  ))
_sym_db.RegisterMessage(CancelJobsRequest)

CancelJobsResponse = _reflection.GeneratedProtocolMessageType('CancelJobsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CANCELJOBSRESPONSE,
  __module__ = 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.CancelJobsResponse)
  ))
_sym_db.RegisterMessage(CancelJobsResponse)

GetJobsRequest = _reflection.GeneratedProtocolMessageType('GetJobsRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETJOBSREQUEST,
  __module__ = 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetJobsRequest)
  ))
_sym_db.RegisterMessage(GetJobsRequest)

GetJobsResponse = _reflection.GeneratedProtocolMessageType('GetJobsResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETJOBSRESPONSE,
  __module__ = 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetJobsResponse)
  ))
_sym_db.RegisterMessage(GetJobsResponse)



_JOBSERVICE = _descriptor.ServiceDescriptor(
  name='JobService',
  full_name='xgt.JobService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=955,
  serialized_end=1177,
  methods=[
  _descriptor.MethodDescriptor(
    name='ScheduleJobsCypher',
    full_name='xgt.JobService.ScheduleJobsCypher',
    index=0,
    containing_service=None,
    input_type=_SCHEDULEJOBSCYPHERREQUEST,
    output_type=_SCHEDULEJOBSCYPHERRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CancelJobs',
    full_name='xgt.JobService.CancelJobs',
    index=1,
    containing_service=None,
    input_type=_CANCELJOBSREQUEST,
    output_type=_CANCELJOBSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetJobs',
    full_name='xgt.JobService.GetJobs',
    index=2,
    containing_service=None,
    input_type=_GETJOBSREQUEST,
    output_type=_GETJOBSRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_JOBSERVICE)

DESCRIPTOR.services_by_name['JobService'] = _JOBSERVICE

# @@protoc_insertion_point(module_scope)
