# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AdminService.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ErrorMessages_pb2 as ErrorMessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='AdminService.proto',
  package='xgt',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x12\x41\x64minService.proto\x12\x03xgt\x1a\x13\x45rrorMessages.proto\"`\n\x17\x43hangeErrorCountRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12)\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x19.xgt.ErrorCountActionEnum\"J\n\x18\x43hangeErrorCountResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x13\n\x0b\x65rror_count\x18\x02 \x01(\x05\"/\n\x11IdentifierRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\"Q\n\x12IdentifierResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12 \n\x18server_unique_identifier\x18\x02 \x01(\x04\"7\n\x19\x46reeUserMemorySizeRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\"Q\n\x1a\x46reeUserMemorySizeResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x18\n\x10\x66ree_memory_size\x18\x02 \x01(\x03\"6\n\x18MaxUserMemorySizeRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\"I\n\x19MaxUserMemorySizeResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x11\n\tpool_size\x18\x02 \x01(\x03\"<\n\x0fShutdownRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12\r\n\x05\x66orce\x18\x02 \x01(\x08\"-\n\x10ShutdownResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\"/\n\x11StatReportRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\"I\n\x12StatReportResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x18\n\x10stat_report_json\x18\x02 \x01(\t\".\n\x10StatResetRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\".\n\x11StatResetResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\",\n\x0eVersionRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\"=\n\x0fVersionResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x0f\n\x07version\x18\x02 \x01(\t*T\n\x14\x45rrorCountActionEnum\x12\x1e\n\x1aUNKNOWN_ERROR_COUNT_ACTION\x10\x00\x12\r\n\tINCREMENT\x10\x01\x12\r\n\tDECREMENT\x10\x02\x32\xc3\x04\n\x0c\x41\x64minService\x12Q\n\x10\x43hangeErrorCount\x12\x1c.xgt.ChangeErrorCountRequest\x1a\x1d.xgt.ChangeErrorCountResponse\"\x00\x12?\n\nIdentifier\x12\x16.xgt.IdentifierRequest\x1a\x17.xgt.IdentifierResponse\"\x00\x12W\n\x12\x46reeUserMemorySize\x12\x1e.xgt.FreeUserMemorySizeRequest\x1a\x1f.xgt.FreeUserMemorySizeResponse\"\x00\x12T\n\x11MaxUserMemorySize\x12\x1d.xgt.MaxUserMemorySizeRequest\x1a\x1e.xgt.MaxUserMemorySizeResponse\"\x00\x12\x39\n\x08Shutdown\x12\x14.xgt.ShutdownRequest\x1a\x15.xgt.ShutdownResponse\"\x00\x12?\n\nStatReport\x12\x16.xgt.StatReportRequest\x1a\x17.xgt.StatReportResponse\"\x00\x12<\n\tStatReset\x12\x15.xgt.StatResetRequest\x1a\x16.xgt.StatResetResponse\"\x00\x12\x36\n\x07Version\x12\x13.xgt.VersionRequest\x1a\x14.xgt.VersionResponse\"\x00\x62\x06proto3')
  ,
  dependencies=[ErrorMessages__pb2.DESCRIPTOR,])

_ERRORCOUNTACTIONENUM = _descriptor.EnumDescriptor(
  name='ErrorCountActionEnum',
  full_name='xgt.ErrorCountActionEnum',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_ERROR_COUNT_ACTION', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCREMENT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DECREMENT', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1063,
  serialized_end=1147,
)
_sym_db.RegisterEnumDescriptor(_ERRORCOUNTACTIONENUM)

ErrorCountActionEnum = enum_type_wrapper.EnumTypeWrapper(_ERRORCOUNTACTIONENUM)
UNKNOWN_ERROR_COUNT_ACTION = 0
INCREMENT = 1
DECREMENT = 2



_CHANGEERRORCOUNTREQUEST = _descriptor.Descriptor(
  name='ChangeErrorCountRequest',
  full_name='xgt.ChangeErrorCountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.ChangeErrorCountRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='xgt.ChangeErrorCountRequest.action', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48,
  serialized_end=144,
)


_CHANGEERRORCOUNTRESPONSE = _descriptor.Descriptor(
  name='ChangeErrorCountResponse',
  full_name='xgt.ChangeErrorCountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.ChangeErrorCountResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_count', full_name='xgt.ChangeErrorCountResponse.error_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=220,
)


_IDENTIFIERREQUEST = _descriptor.Descriptor(
  name='IdentifierRequest',
  full_name='xgt.IdentifierRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.IdentifierRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=269,
)


_IDENTIFIERRESPONSE = _descriptor.Descriptor(
  name='IdentifierResponse',
  full_name='xgt.IdentifierResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.IdentifierResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='server_unique_identifier', full_name='xgt.IdentifierResponse.server_unique_identifier', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=271,
  serialized_end=352,
)


_FREEUSERMEMORYSIZEREQUEST = _descriptor.Descriptor(
  name='FreeUserMemorySizeRequest',
  full_name='xgt.FreeUserMemorySizeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.FreeUserMemorySizeRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=354,
  serialized_end=409,
)


_FREEUSERMEMORYSIZERESPONSE = _descriptor.Descriptor(
  name='FreeUserMemorySizeResponse',
  full_name='xgt.FreeUserMemorySizeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.FreeUserMemorySizeResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='free_memory_size', full_name='xgt.FreeUserMemorySizeResponse.free_memory_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=411,
  serialized_end=492,
)


_MAXUSERMEMORYSIZEREQUEST = _descriptor.Descriptor(
  name='MaxUserMemorySizeRequest',
  full_name='xgt.MaxUserMemorySizeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.MaxUserMemorySizeRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=494,
  serialized_end=548,
)


_MAXUSERMEMORYSIZERESPONSE = _descriptor.Descriptor(
  name='MaxUserMemorySizeResponse',
  full_name='xgt.MaxUserMemorySizeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.MaxUserMemorySizeResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pool_size', full_name='xgt.MaxUserMemorySizeResponse.pool_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=550,
  serialized_end=623,
)


_SHUTDOWNREQUEST = _descriptor.Descriptor(
  name='ShutdownRequest',
  full_name='xgt.ShutdownRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.ShutdownRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='force', full_name='xgt.ShutdownRequest.force', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=625,
  serialized_end=685,
)


_SHUTDOWNRESPONSE = _descriptor.Descriptor(
  name='ShutdownResponse',
  full_name='xgt.ShutdownResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.ShutdownResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=687,
  serialized_end=732,
)


_STATREPORTREQUEST = _descriptor.Descriptor(
  name='StatReportRequest',
  full_name='xgt.StatReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.StatReportRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=734,
  serialized_end=781,
)


_STATREPORTRESPONSE = _descriptor.Descriptor(
  name='StatReportResponse',
  full_name='xgt.StatReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.StatReportResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stat_report_json', full_name='xgt.StatReportResponse.stat_report_json', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=783,
  serialized_end=856,
)


_STATRESETREQUEST = _descriptor.Descriptor(
  name='StatResetRequest',
  full_name='xgt.StatResetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.StatResetRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=858,
  serialized_end=904,
)


_STATRESETRESPONSE = _descriptor.Descriptor(
  name='StatResetResponse',
  full_name='xgt.StatResetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.StatResetResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=906,
  serialized_end=952,
)


_VERSIONREQUEST = _descriptor.Descriptor(
  name='VersionRequest',
  full_name='xgt.VersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.VersionRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=954,
  serialized_end=998,
)


_VERSIONRESPONSE = _descriptor.Descriptor(
  name='VersionResponse',
  full_name='xgt.VersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.VersionResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='xgt.VersionResponse.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1000,
  serialized_end=1061,
)

_CHANGEERRORCOUNTREQUEST.fields_by_name['action'].enum_type = _ERRORCOUNTACTIONENUM
_CHANGEERRORCOUNTRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_IDENTIFIERRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_FREEUSERMEMORYSIZERESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_MAXUSERMEMORYSIZERESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_SHUTDOWNRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_STATREPORTRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_STATRESETRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_VERSIONRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
DESCRIPTOR.message_types_by_name['ChangeErrorCountRequest'] = _CHANGEERRORCOUNTREQUEST
DESCRIPTOR.message_types_by_name['ChangeErrorCountResponse'] = _CHANGEERRORCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['IdentifierRequest'] = _IDENTIFIERREQUEST
DESCRIPTOR.message_types_by_name['IdentifierResponse'] = _IDENTIFIERRESPONSE
DESCRIPTOR.message_types_by_name['FreeUserMemorySizeRequest'] = _FREEUSERMEMORYSIZEREQUEST
DESCRIPTOR.message_types_by_name['FreeUserMemorySizeResponse'] = _FREEUSERMEMORYSIZERESPONSE
DESCRIPTOR.message_types_by_name['MaxUserMemorySizeRequest'] = _MAXUSERMEMORYSIZEREQUEST
DESCRIPTOR.message_types_by_name['MaxUserMemorySizeResponse'] = _MAXUSERMEMORYSIZERESPONSE
DESCRIPTOR.message_types_by_name['ShutdownRequest'] = _SHUTDOWNREQUEST
DESCRIPTOR.message_types_by_name['ShutdownResponse'] = _SHUTDOWNRESPONSE
DESCRIPTOR.message_types_by_name['StatReportRequest'] = _STATREPORTREQUEST
DESCRIPTOR.message_types_by_name['StatReportResponse'] = _STATREPORTRESPONSE
DESCRIPTOR.message_types_by_name['StatResetRequest'] = _STATRESETREQUEST
DESCRIPTOR.message_types_by_name['StatResetResponse'] = _STATRESETRESPONSE
DESCRIPTOR.message_types_by_name['VersionRequest'] = _VERSIONREQUEST
DESCRIPTOR.message_types_by_name['VersionResponse'] = _VERSIONRESPONSE
DESCRIPTOR.enum_types_by_name['ErrorCountActionEnum'] = _ERRORCOUNTACTIONENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ChangeErrorCountRequest = _reflection.GeneratedProtocolMessageType('ChangeErrorCountRequest', (_message.Message,), dict(
  DESCRIPTOR = _CHANGEERRORCOUNTREQUEST,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ChangeErrorCountRequest)
  ))
_sym_db.RegisterMessage(ChangeErrorCountRequest)

ChangeErrorCountResponse = _reflection.GeneratedProtocolMessageType('ChangeErrorCountResponse', (_message.Message,), dict(
  DESCRIPTOR = _CHANGEERRORCOUNTRESPONSE,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ChangeErrorCountResponse)
  ))
_sym_db.RegisterMessage(ChangeErrorCountResponse)

IdentifierRequest = _reflection.GeneratedProtocolMessageType('IdentifierRequest', (_message.Message,), dict(
  DESCRIPTOR = _IDENTIFIERREQUEST,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.IdentifierRequest)
  ))
_sym_db.RegisterMessage(IdentifierRequest)

IdentifierResponse = _reflection.GeneratedProtocolMessageType('IdentifierResponse', (_message.Message,), dict(
  DESCRIPTOR = _IDENTIFIERRESPONSE,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.IdentifierResponse)
  ))
_sym_db.RegisterMessage(IdentifierResponse)

FreeUserMemorySizeRequest = _reflection.GeneratedProtocolMessageType('FreeUserMemorySizeRequest', (_message.Message,), dict(
  DESCRIPTOR = _FREEUSERMEMORYSIZEREQUEST,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.FreeUserMemorySizeRequest)
  ))
_sym_db.RegisterMessage(FreeUserMemorySizeRequest)

FreeUserMemorySizeResponse = _reflection.GeneratedProtocolMessageType('FreeUserMemorySizeResponse', (_message.Message,), dict(
  DESCRIPTOR = _FREEUSERMEMORYSIZERESPONSE,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.FreeUserMemorySizeResponse)
  ))
_sym_db.RegisterMessage(FreeUserMemorySizeResponse)

MaxUserMemorySizeRequest = _reflection.GeneratedProtocolMessageType('MaxUserMemorySizeRequest', (_message.Message,), dict(
  DESCRIPTOR = _MAXUSERMEMORYSIZEREQUEST,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.MaxUserMemorySizeRequest)
  ))
_sym_db.RegisterMessage(MaxUserMemorySizeRequest)

MaxUserMemorySizeResponse = _reflection.GeneratedProtocolMessageType('MaxUserMemorySizeResponse', (_message.Message,), dict(
  DESCRIPTOR = _MAXUSERMEMORYSIZERESPONSE,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.MaxUserMemorySizeResponse)
  ))
_sym_db.RegisterMessage(MaxUserMemorySizeResponse)

ShutdownRequest = _reflection.GeneratedProtocolMessageType('ShutdownRequest', (_message.Message,), dict(
  DESCRIPTOR = _SHUTDOWNREQUEST,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ShutdownRequest)
  ))
_sym_db.RegisterMessage(ShutdownRequest)

ShutdownResponse = _reflection.GeneratedProtocolMessageType('ShutdownResponse', (_message.Message,), dict(
  DESCRIPTOR = _SHUTDOWNRESPONSE,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ShutdownResponse)
  ))
_sym_db.RegisterMessage(ShutdownResponse)

StatReportRequest = _reflection.GeneratedProtocolMessageType('StatReportRequest', (_message.Message,), dict(
  DESCRIPTOR = _STATREPORTREQUEST,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.StatReportRequest)
  ))
_sym_db.RegisterMessage(StatReportRequest)

StatReportResponse = _reflection.GeneratedProtocolMessageType('StatReportResponse', (_message.Message,), dict(
  DESCRIPTOR = _STATREPORTRESPONSE,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.StatReportResponse)
  ))
_sym_db.RegisterMessage(StatReportResponse)

StatResetRequest = _reflection.GeneratedProtocolMessageType('StatResetRequest', (_message.Message,), dict(
  DESCRIPTOR = _STATRESETREQUEST,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.StatResetRequest)
  ))
_sym_db.RegisterMessage(StatResetRequest)

StatResetResponse = _reflection.GeneratedProtocolMessageType('StatResetResponse', (_message.Message,), dict(
  DESCRIPTOR = _STATRESETRESPONSE,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.StatResetResponse)
  ))
_sym_db.RegisterMessage(StatResetResponse)

VersionRequest = _reflection.GeneratedProtocolMessageType('VersionRequest', (_message.Message,), dict(
  DESCRIPTOR = _VERSIONREQUEST,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.VersionRequest)
  ))
_sym_db.RegisterMessage(VersionRequest)

VersionResponse = _reflection.GeneratedProtocolMessageType('VersionResponse', (_message.Message,), dict(
  DESCRIPTOR = _VERSIONRESPONSE,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.VersionResponse)
  ))
_sym_db.RegisterMessage(VersionResponse)



_ADMINSERVICE = _descriptor.ServiceDescriptor(
  name='AdminService',
  full_name='xgt.AdminService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1150,
  serialized_end=1729,
  methods=[
  _descriptor.MethodDescriptor(
    name='ChangeErrorCount',
    full_name='xgt.AdminService.ChangeErrorCount',
    index=0,
    containing_service=None,
    input_type=_CHANGEERRORCOUNTREQUEST,
    output_type=_CHANGEERRORCOUNTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Identifier',
    full_name='xgt.AdminService.Identifier',
    index=1,
    containing_service=None,
    input_type=_IDENTIFIERREQUEST,
    output_type=_IDENTIFIERRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='FreeUserMemorySize',
    full_name='xgt.AdminService.FreeUserMemorySize',
    index=2,
    containing_service=None,
    input_type=_FREEUSERMEMORYSIZEREQUEST,
    output_type=_FREEUSERMEMORYSIZERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='MaxUserMemorySize',
    full_name='xgt.AdminService.MaxUserMemorySize',
    index=3,
    containing_service=None,
    input_type=_MAXUSERMEMORYSIZEREQUEST,
    output_type=_MAXUSERMEMORYSIZERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Shutdown',
    full_name='xgt.AdminService.Shutdown',
    index=4,
    containing_service=None,
    input_type=_SHUTDOWNREQUEST,
    output_type=_SHUTDOWNRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='StatReport',
    full_name='xgt.AdminService.StatReport',
    index=5,
    containing_service=None,
    input_type=_STATREPORTREQUEST,
    output_type=_STATREPORTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='StatReset',
    full_name='xgt.AdminService.StatReset',
    index=6,
    containing_service=None,
    input_type=_STATRESETREQUEST,
    output_type=_STATRESETRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Version',
    full_name='xgt.AdminService.Version',
    index=7,
    containing_service=None,
    input_type=_VERSIONREQUEST,
    output_type=_VERSIONRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_ADMINSERVICE)

DESCRIPTOR.services_by_name['AdminService'] = _ADMINSERVICE

# @@protoc_insertion_point(module_scope)
