# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: DataService.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import ErrorMessages_pb2 as ErrorMessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='DataService.proto',
  package='xgt',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x11\x44\x61taService.proto\x12\x03xgt\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x13\x45rrorMessages.proto\"\xab\x01\n\x11UploadDataRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12\x17\n\x0frepository_name\x18\x02 \x01(\t\x12&\n\x0c\x63ontent_type\x18\x03 \x01(\x0e\x32\x10.xgt.ContentType\x12(\n\x0bheader_mode\x18\x04 \x01(\x0e\x32\x13.xgt.HeaderModeEnum\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\x0c\"/\n\x12UploadDataResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\"\xe4\x01\n\x13\x44ownloadDataRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12\x17\n\x0frepository_name\x18\x02 \x01(\t\x12,\n\x06offset\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12,\n\x06length\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x14\n\x0cwith_headers\x18\x05 \x01(\x08\x12&\n\x0c\x63ontent_type\x18\x06 \x01(\x0e\x32\x10.xgt.ContentType\"B\n\x14\x44ownloadDataResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\"\x9d\x01\n\x10IngestUriRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12\x17\n\x0frepository_name\x18\x02 \x01(\t\x12(\n\x0bheader_mode\x18\x03 \x01(\x0e\x32\x13.xgt.HeaderModeEnum\x12\x15\n\rauthorization\x18\x04 \x01(\t\x12\x13\n\x0b\x63ontent_uri\x18\x05 \x03(\t\".\n\x11IngestUriResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\"q\n\x0f\x45gestUriRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12\x17\n\x0frepository_name\x18\x02 \x01(\t\x12\x13\n\x0b\x63ontent_uri\x18\x03 \x01(\t\x12\x14\n\x0cwith_headers\x18\x04 \x01(\x08\"-\n\x10\x45gestUriResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error*_\n\x0eHeaderModeEnum\x12\x17\n\x13UNKNOWN_HEADER_MODE\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x12\n\x0eIGNORE_HEADERS\x10\x02\x12\n\n\x06NORMAL\x10\x03\x12\n\n\x06STRICT\x10\x04*R\n\x0b\x43ontentType\x12\x13\n\x0fUNKNOWN_CONTENT\x10\x00\x12\x07\n\x03\x43SV\x10\x01\x12\x08\n\x04JSON\x10\x02\x12\x07\n\x03ZIP\x10\x03\x12\x08\n\x04GZIP\x10\x04\x12\x08\n\x04TZIP\x10\x05\x32\x92\x02\n\x0b\x44\x61taService\x12\x41\n\nUploadData\x12\x16.xgt.UploadDataRequest\x1a\x17.xgt.UploadDataResponse\"\x00(\x01\x12G\n\x0c\x44ownloadData\x12\x18.xgt.DownloadDataRequest\x1a\x19.xgt.DownloadDataResponse\"\x00\x30\x01\x12<\n\tIngestUri\x12\x15.xgt.IngestUriRequest\x1a\x16.xgt.IngestUriResponse\"\x00\x12\x39\n\x08\x45gestUri\x12\x14.xgt.EgestUriRequest\x1a\x15.xgt.EgestUriResponse\"\x00\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,ErrorMessages__pb2.DESCRIPTOR,])

_HEADERMODEENUM = _descriptor.EnumDescriptor(
  name='HeaderModeEnum',
  full_name='xgt.HeaderModeEnum',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_HEADER_MODE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NONE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IGNORE_HEADERS', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NORMAL', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRICT', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=971,
  serialized_end=1066,
)
_sym_db.RegisterEnumDescriptor(_HEADERMODEENUM)

HeaderModeEnum = enum_type_wrapper.EnumTypeWrapper(_HEADERMODEENUM)
_CONTENTTYPE = _descriptor.EnumDescriptor(
  name='ContentType',
  full_name='xgt.ContentType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_CONTENT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CSV', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JSON', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ZIP', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GZIP', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TZIP', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1068,
  serialized_end=1150,
)
_sym_db.RegisterEnumDescriptor(_CONTENTTYPE)

ContentType = enum_type_wrapper.EnumTypeWrapper(_CONTENTTYPE)
UNKNOWN_HEADER_MODE = 0
NONE = 1
IGNORE_HEADERS = 2
NORMAL = 3
STRICT = 4
UNKNOWN_CONTENT = 0
CSV = 1
JSON = 2
ZIP = 3
GZIP = 4
TZIP = 5



_UPLOADDATAREQUEST = _descriptor.Descriptor(
  name='UploadDataRequest',
  full_name='xgt.UploadDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.UploadDataRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repository_name', full_name='xgt.UploadDataRequest.repository_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='xgt.UploadDataRequest.content_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_mode', full_name='xgt.UploadDataRequest.header_mode', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='xgt.UploadDataRequest.content', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=251,
)


_UPLOADDATARESPONSE = _descriptor.Descriptor(
  name='UploadDataResponse',
  full_name='xgt.UploadDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.UploadDataResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=253,
  serialized_end=300,
)


_DOWNLOADDATAREQUEST = _descriptor.Descriptor(
  name='DownloadDataRequest',
  full_name='xgt.DownloadDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.DownloadDataRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repository_name', full_name='xgt.DownloadDataRequest.repository_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='xgt.DownloadDataRequest.offset', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='length', full_name='xgt.DownloadDataRequest.length', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='with_headers', full_name='xgt.DownloadDataRequest.with_headers', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='xgt.DownloadDataRequest.content_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=303,
  serialized_end=531,
)


_DOWNLOADDATARESPONSE = _descriptor.Descriptor(
  name='DownloadDataResponse',
  full_name='xgt.DownloadDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.DownloadDataResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='xgt.DownloadDataResponse.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=533,
  serialized_end=599,
)


_INGESTURIREQUEST = _descriptor.Descriptor(
  name='IngestUriRequest',
  full_name='xgt.IngestUriRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.IngestUriRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repository_name', full_name='xgt.IngestUriRequest.repository_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_mode', full_name='xgt.IngestUriRequest.header_mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='authorization', full_name='xgt.IngestUriRequest.authorization', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_uri', full_name='xgt.IngestUriRequest.content_uri', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=602,
  serialized_end=759,
)


_INGESTURIRESPONSE = _descriptor.Descriptor(
  name='IngestUriResponse',
  full_name='xgt.IngestUriResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.IngestUriResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=761,
  serialized_end=807,
)


_EGESTURIREQUEST = _descriptor.Descriptor(
  name='EgestUriRequest',
  full_name='xgt.EgestUriRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.EgestUriRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repository_name', full_name='xgt.EgestUriRequest.repository_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_uri', full_name='xgt.EgestUriRequest.content_uri', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='with_headers', full_name='xgt.EgestUriRequest.with_headers', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=809,
  serialized_end=922,
)


_EGESTURIRESPONSE = _descriptor.Descriptor(
  name='EgestUriResponse',
  full_name='xgt.EgestUriResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.EgestUriResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=924,
  serialized_end=969,
)

_UPLOADDATAREQUEST.fields_by_name['content_type'].enum_type = _CONTENTTYPE
_UPLOADDATAREQUEST.fields_by_name['header_mode'].enum_type = _HEADERMODEENUM
_UPLOADDATARESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_DOWNLOADDATAREQUEST.fields_by_name['offset'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT64VALUE
_DOWNLOADDATAREQUEST.fields_by_name['length'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT64VALUE
_DOWNLOADDATAREQUEST.fields_by_name['content_type'].enum_type = _CONTENTTYPE
_DOWNLOADDATARESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_INGESTURIREQUEST.fields_by_name['header_mode'].enum_type = _HEADERMODEENUM
_INGESTURIRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_EGESTURIRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
DESCRIPTOR.message_types_by_name['UploadDataRequest'] = _UPLOADDATAREQUEST
DESCRIPTOR.message_types_by_name['UploadDataResponse'] = _UPLOADDATARESPONSE
DESCRIPTOR.message_types_by_name['DownloadDataRequest'] = _DOWNLOADDATAREQUEST
DESCRIPTOR.message_types_by_name['DownloadDataResponse'] = _DOWNLOADDATARESPONSE
DESCRIPTOR.message_types_by_name['IngestUriRequest'] = _INGESTURIREQUEST
DESCRIPTOR.message_types_by_name['IngestUriResponse'] = _INGESTURIRESPONSE
DESCRIPTOR.message_types_by_name['EgestUriRequest'] = _EGESTURIREQUEST
DESCRIPTOR.message_types_by_name['EgestUriResponse'] = _EGESTURIRESPONSE
DESCRIPTOR.enum_types_by_name['HeaderModeEnum'] = _HEADERMODEENUM
DESCRIPTOR.enum_types_by_name['ContentType'] = _CONTENTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UploadDataRequest = _reflection.GeneratedProtocolMessageType('UploadDataRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPLOADDATAREQUEST,
  __module__ = 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.UploadDataRequest)
  ))
_sym_db.RegisterMessage(UploadDataRequest)

UploadDataResponse = _reflection.GeneratedProtocolMessageType('UploadDataResponse', (_message.Message,), dict(
  DESCRIPTOR = _UPLOADDATARESPONSE,
  __module__ = 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.UploadDataResponse)
  ))
_sym_db.RegisterMessage(UploadDataResponse)

DownloadDataRequest = _reflection.GeneratedProtocolMessageType('DownloadDataRequest', (_message.Message,), dict(
  DESCRIPTOR = _DOWNLOADDATAREQUEST,
  __module__ = 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.DownloadDataRequest)
  ))
_sym_db.RegisterMessage(DownloadDataRequest)

DownloadDataResponse = _reflection.GeneratedProtocolMessageType('DownloadDataResponse', (_message.Message,), dict(
  DESCRIPTOR = _DOWNLOADDATARESPONSE,
  __module__ = 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.DownloadDataResponse)
  ))
_sym_db.RegisterMessage(DownloadDataResponse)

IngestUriRequest = _reflection.GeneratedProtocolMessageType('IngestUriRequest', (_message.Message,), dict(
  DESCRIPTOR = _INGESTURIREQUEST,
  __module__ = 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.IngestUriRequest)
  ))
_sym_db.RegisterMessage(IngestUriRequest)

IngestUriResponse = _reflection.GeneratedProtocolMessageType('IngestUriResponse', (_message.Message,), dict(
  DESCRIPTOR = _INGESTURIRESPONSE,
  __module__ = 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.IngestUriResponse)
  ))
_sym_db.RegisterMessage(IngestUriResponse)

EgestUriRequest = _reflection.GeneratedProtocolMessageType('EgestUriRequest', (_message.Message,), dict(
  DESCRIPTOR = _EGESTURIREQUEST,
  __module__ = 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.EgestUriRequest)
  ))
_sym_db.RegisterMessage(EgestUriRequest)

EgestUriResponse = _reflection.GeneratedProtocolMessageType('EgestUriResponse', (_message.Message,), dict(
  DESCRIPTOR = _EGESTURIRESPONSE,
  __module__ = 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.EgestUriResponse)
  ))
_sym_db.RegisterMessage(EgestUriResponse)



_DATASERVICE = _descriptor.ServiceDescriptor(
  name='DataService',
  full_name='xgt.DataService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1153,
  serialized_end=1427,
  methods=[
  _descriptor.MethodDescriptor(
    name='UploadData',
    full_name='xgt.DataService.UploadData',
    index=0,
    containing_service=None,
    input_type=_UPLOADDATAREQUEST,
    output_type=_UPLOADDATARESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DownloadData',
    full_name='xgt.DataService.DownloadData',
    index=1,
    containing_service=None,
    input_type=_DOWNLOADDATAREQUEST,
    output_type=_DOWNLOADDATARESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='IngestUri',
    full_name='xgt.DataService.IngestUri',
    index=2,
    containing_service=None,
    input_type=_INGESTURIREQUEST,
    output_type=_INGESTURIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='EgestUri',
    full_name='xgt.DataService.EgestUri',
    index=3,
    containing_service=None,
    input_type=_EGESTURIREQUEST,
    output_type=_EGESTURIRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATASERVICE)

DESCRIPTOR.services_by_name['DataService'] = _DATASERVICE

# @@protoc_insertion_point(module_scope)
